@@ -1,7 +1,7 @@
 __title__ = "sewer"
 __description__ = "Sewer is a programmatic Lets Encrypt(ACME) client"
-__url__ = "https://github.com/komuW/sewer"
-__version__ = "0.2.4.1"
+__url__ = "https://github.com/komuw/sewer"
+__version__ = "0.8.1"
 __author__ = "komuW"
 __author_email__ = "komuw05@gmail.com"
 __license__ = "MIT"
